<?php
/**
 * Custom template tags for this theme
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package AMPLight
 */


if ( ! function_exists( 'amplight_posted_on' ) ) :
	/**
	 * Prints HTML with meta information for the current post-date/time.
	 */
	function amplight_posted_on() {
		$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
		if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
			$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
		}

		$time_string = sprintf( $time_string,
			esc_attr( get_the_date( DATE_W3C ) ),
			esc_html( get_the_date() ),
			esc_attr( get_the_modified_date( DATE_W3C ) ),
			esc_html( get_the_modified_date() )
		);

		$posted_on = sprintf(
			/* translators: %s: post date. */
			esc_html_x( 'Posted on %s', 'post date', 'amplight' ),
			'<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . $time_string . '</a>'
		);

		echo '<span class="posted-on">' . $posted_on . '</span>'; // WPCS: XSS OK.

	}
endif;

if ( ! function_exists( 'amplight_posted_by' ) ) :
	/**
	 * Prints HTML with meta information for the current author.
	 */
	function amplight_posted_by() {
		$byline = sprintf(
			/* translators: %s: post author. */
			esc_html_x( 'by %s', 'post author', 'amplight' ),
			'<span class="author vcard"><a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html( get_the_author() ) . '</a></span>'
		);

		echo '<span class="byline"> ' . $byline . '</span>'; // WPCS: XSS OK.

	}
endif;

if ( ! function_exists( 'amplight_entry_footer' ) ) :
	/**
	 * Prints HTML with meta information for the categories, tags and comments.
	 */
	function amplight_entry_footer() {
		// Hide category and tag text for pages.
		if ( 'post' === get_post_type() ) {
			/* translators: used between list items, there is a space after the comma */
			$categories_list = get_the_category_list( esc_html__( ', ', 'amplight' ) );
			if ( $categories_list ) {
				/* translators: 1: list of categories. */
				printf( '<span class="cat-links">' . esc_html__( 'Posted in %1$s', 'amplight' ) . '</span>', $categories_list ); // WPCS: XSS OK.
			}

			/* translators: used between list items, there is a space after the comma */
			$tags_list = get_the_tag_list( '', esc_html_x( ', ', 'list item separator', 'amplight' ) );
			if ( $tags_list ) {
				/* translators: 1: list of tags. */
				printf( '<span class="tags-links">' . esc_html__( 'Tagged %1$s', 'amplight' ) . '</span>', $tags_list ); // WPCS: XSS OK.
			}
		}

		if ( ! is_single() && ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
			echo '<span class="comments-link">';
			comments_popup_link(
				sprintf(
					wp_kses(
						/* translators: %s: post title */
						__( 'Leave a Comment<span class="screen-reader-text"> on %s</span>', 'amplight' ),
						array(
							'span' => array(
								'class' => array(),
							),
						)
					),
					get_the_title()
				)
			);
			echo '</span>';
		}

		edit_post_link(
			sprintf(
				wp_kses(
					/* translators: %s: Name of current post. Only visible to screen readers */
					__( 'Edit <span class="screen-reader-text">%s</span>', 'amplight' ),
					array(
						'span' => array(
							'class' => array(),
						),
					)
				),
				get_the_title()
			),
			'<span class="edit-link">',
			'</span>'
		);
	}
endif;

if ( ! function_exists( 'amplight_post_thumbnail' ) ) :
	/**
	 * Displays an optional post thumbnail.
	 *
	 * Wraps the post thumbnail in an anchor element on index views, or a div
	 * element when on single views.
	 */
	function amplight_post_thumbnail() {
		if ( post_password_required() || is_attachment() || ! has_post_thumbnail() ) {
			return;
		}

		if ( is_singular() ) :
			?>

			<div class="post-thumbnail">
				<?php the_post_thumbnail(); ?>
			</div><!-- .post-thumbnail -->

		<?php else : ?>

		<a class="post-thumbnail" href="<?php the_permalink(); ?>" aria-hidden="true" tabindex="-1">
			<?php
			the_post_thumbnail( 'post-thumbnail', array(
				'alt' => the_title_attribute( array(
					'echo' => false,
				) ),
			) );
			?>
		</a>

		<?php
		endif; // End is_singular().
	}
endif;



/**
|------------------------------------------------------------------------------
| Related Posts
|------------------------------------------------------------------------------
|
| You can show related posts by Categories or Tags. 
| It has two options to show related posts
|
| 1. Thumbnail related posts (default)
| 2. List of related posts
| 
| @return void
|
*/

if ( ! function_exists('amplight_related_posts') ) :

	function amplight_related_posts() {
		
		global $post;

		$taxonomy = get_theme_mod('amplight_related_post_taxonomy', 'category');
		$numberRelated = get_theme_mod('amplight_number_related_posts', '9');

		$args =  array();

		if ( $taxonomy == 'tag' ) {

			$tags = wp_get_post_tags( $post->ID );
			$arr_tags = array();

			foreach( $tags as $tag ) {

				array_push($arr_tags, $tag->term_id);

			}
			
			if (!empty($arr_tags)) { 
				$args = array(
					'tag__in'			=> $arr_tags,  
					'post__not_in'		=> array($post->ID),  
					'posts_per_page'	=> $numberRelated,
				); 
			}

		} else {

			$args = array( 
				'category__in'		=> wp_get_post_categories($post->ID), 
				'posts_per_page'	=> $numberRelated, 
				'post__not_in'		=> array($post->ID) 
			);

		}

		if ( ! empty( $args ) ) {
			
			$posts = get_posts( $args );

			if ( $posts ) {
			?>

			<div class="fbox posts-related clearfix">
				
				<div class="swidget">
					<h3 class="related-title"><?php esc_html_e('Related Post', 'amplight') ?></h3>
				</div>
				
				<?php
					$related_style = 'grid';
					if ( $related_style == 'grid' ) :
				?>
					
					<ul class="related-grid">
						
						<?php
						foreach ( $posts as $p ) {
						?>
							
							<li>
										
								<?php if ( has_post_thumbnail( $p->ID ) ) : ?>

									<a href="<?php echo esc_url( get_the_permalink( $p->ID ) ) ?>">
										<?php echo get_the_post_thumbnail( $p->ID, 'amplight-small' ) ?>
									</a>

								<?php else : ?>

									<a href="<?php echo esc_url( get_the_permalink( $p->ID ) ) ?>">
										<img class="wp-post-image" src="<?php echo esc_url( get_template_directory_uri() ); ?>/images/default-small.jpg" alt="<?php the_title_attribute() ?>" />
									</a>

								<?php endif; ?>
								
								<a class="related-ptitle" href="<?php echo esc_url( get_the_permalink( $p->ID ) ) ?>"><?php echo esc_html( get_the_title( $p->ID ) ) ?></a>
							
							</li>

						<?php
							}
						?>

					</ul>

					<?php
						else :
					?>

					<ul class="related-list">
						
						<?php
						foreach ( $posts as $p ) {
							?>
							
							<li>												
								
								<a href="<?php echo esc_url( get_the_permalink($p->ID) ) ?>"><?php echo get_the_title($p->ID) ?></a>								
								
							</li>

						<?php
							}
						?>
					</ul>

					<?php endif; ?>

				</div>
			
				<?php
			}
		}
	}
endif;


if ( ! function_exists( 'amplight_excerpt_length' ) ) {

	/**
	|------------------------------------------------------------------------------
	| Excerpt length | @return integer
	|------------------------------------------------------------------------------
	*/

	function amplight_excerpt_length($length) {

		if ( is_admin() ) {
			return $length;
		}

		$number = intval ( get_theme_mod('amplight_general_excerpt_lengh') ) > 0 ? intval ( get_theme_mod('amplight_general_excerpt_lengh') ) : $length;
		return $number;
	}
	
}

add_filter( 'excerpt_length', 'amplight_excerpt_length', 999 );


if ( ! function_exists( 'amplight_excerpt_more' ) ) {
	/**
	|------------------------------------------------------------------------------
	| Excerpt ending | @return string
	|------------------------------------------------------------------------------
	*/
	function amplight_excerpt_more( $more ) {
		if ( is_admin() ) {
			return $more;
		}
		return get_theme_mod( 'amplight_general_excerpt_end_text', ' ...' );
	}
	
}

add_filter( 'excerpt_more', 'amplight_excerpt_more' );


